Sealant
=======

.. currentmodule:: pykeen.triples.leakage

.. autoclass:: Sealant
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Sealant.apply

   .. rubric:: Methods Documentation

   .. automethod:: apply
